package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````8!Y```````!``````````##'````
M`````````$``.``(`$``&@`9``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````,RX````````S+@`````````
M`"````````$````&`````,``````````P&````````#`8```````9`0`````
M``"("0``````````(````````@````8````HP````````"C`8```````*,!@
M``````#P`0```````/`!````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````@+0```````"`M$```````("T0```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`(B_#0!#````80`````````,`````````%@```!'
M``````````````!4`````````$D```!1````7P```#4````G`````````%L`
M``!:`````````$H```!@```````````````#````"0```#,````E````7@``
M`$$```!0````2````"0`````````!P`````````Q````0```````````````
M'@```#L`````````5P````````!"````$0```"@````O````/@`````````]
M````3@``````````````&P```#H````N````0P````````!9````5@``````
M``!2`````0```!H````\````/P```%T`````````````````````````````
M````````````````````````````````````````````"P````4`````````
M```````````.```````````````/`````````!`````````````````````6
M````````````````````````````````````"````!@`````````````````
M```&``````````H````````````````````3`````````"T````4````%0``
M```````7`````@``````````````!`````T````F````+````!D````B````
M```````````@````,@```!\````Y````(P```#0``````````````!T````V
M````(0`````````2````*@```$8`````````*P```#@`````````2P```#``
M``!%````3````$\````I`````````%4```!3`````````#<```!<````'```
M`$0```!-````````````````````````````````````5@$``!(`````````
M`````"$!````````B0,``!(`#`"0.T````````4`````````F@,``!(`#`!P
M'T```````#0`````````#````!(``````````````!4`````````_P,``!(`
M`````````````!X`````````60,``!(`#`!@'D```````)P`````````%@``
M`!$`%P"`Q&````````0`````````(0```!(``````````````$`&````````
M:P(``!(`````````````````````````^@$``!(``````````````*P`````
M````+````!(```"<&D```````#4`````````/P```"``````````````````
M````````8`(``!$`%@!`Q&````````@`````````4P```!(`#0!454``````
M````````````IP,``!(`#`!04$```````$H$````````O0,``!(`#`#P-D``
M`````$T`````````RP,``!(`#`#`.D```````,D`````````60```!(`````
M`````````+P$````````8@```!(``````````````!(!````````<````!(`
M`````````````%<`````````X0,``!(`#`#`0$```````.(`````````[0,`
M`!(`#`"00$```````"(`````````@````!(``````````````'4!````````
MIP(``!(``````````````"\`````````U0(``!(```````````````P`````
M````"`0``!(`#`"P04```````&T`````````1@,``!(```````````````\`
M````````[0(``!(`````````````````````````-P,``!(`````````````
M`&P`````````)`,``!(`````````````````````````C@```!(`````````
M`````%0!````````^P(``!(```````````````(`````````F0```!(`````
M`````````#4#````````/P,``!(``````````````%4`````````#`,``!(`
M`````````````-D`````````%`,``!(``````````````)``````````&`(`
M`!(``````````````$H`````````IP```!(``````````````'<`````````
MH0(``!(``````````````&<`````````D@(``!(``````````````/0`````
M````M0```!(```#L&T```````/@!````````Q0```!(```#\&T```````#4`
M````````_P$``!(``````````````'$`````````U@```!(`````````````
M`(D`````````YP```!(``````````````&4'````````'`,``!(`````````
M`````"$`````````(P,``!(`````````````````````````!0,``!(`````
M````````````````````A`(``!(`````````````````````````?@(``!(`
M````````````````````````%`0``!(`#`"@5$```````"H`````````B@(`
M`!(``````````````#0`````````]@```!(``````````````),!````````
M!0$``!(``````````````-$"````````)@(``!(``````````````-``````
M````$P$``!(``````````````#L;````````!`(``!(``````````````$4`
M````````K@(``!(`````````````````````````Y0(``!(`````````````
M`$P`````````Q`(``!(```````````````P`````````5`,``!``\?]DQ&``
M````````````````(0$``!$`%P"`R6````````@`````````*0$``!(`````
M`````````/T`````````6`(``!(``````````````(\0````````'@(``!(`
M`````````````#$`````````F0(``!(```````````````H`````````40(`
M`!(``````````````$H`````````'`0``!(`#`!`-T```````#H`````````
M-0$``!(``````````````*4`````````/P(``!$`%P"@Q&```````$``````
M````*0,``!(``````````````'P`````````8`,``!``\?^(R6``````````
M````````M0(``!(`````````````````````````]`(``!(`````````````
M`%0`````````2@$``!(``````````````#X`````````70$``!(`````````
M`````)\`````````:@$``!$`%P#@Q&````````$`````````=P$``!$`%P#P
MQ&```````!,`````````J0(``!(``````````````"\`````````.`0``!(`
M#``01D```````#X*````````30,``!``\?]DQ&``````````````````$0``
M`!(```````````````T'````````A@$``!(```````````````L`````````
M100``!(`#`"P/4```````!<!````````5P0``!(`#`!`1$```````,8!````
M````9`0``!$`%@!8Q&````````@`````````D0$``!(``````````````)P`
M````````O`(``!(``````````````$H`````````W`(``!(`````````````
M`)L`````````=`(``!$`%P`@Q6````````@`````````,`,``!(`````````
M`````'X`````````;@0``!(`#`#0/D```````+X!````````>P0``!(`#``@
M0D```````!@"````````%@0``!(`"@`8&D``````````````````H`$``!(`
M`````````````'$`````````MP$``!(``````````````"X)`````````&QI
M8G!E<FPN<V\`<&5R;%]F<F5E`%!,7W1H<E]K97D`<&5R;%]P87)S90!097)L
M7V%T9F]R:U]U;FQO8VL`7TIV7U)E9VES=&5R0VQA<W-E<P!?9FEN:0!P97)L
M7W)U;@!097)L7V%V7W-H:69T`%!E<FQ?9W9?9F5T8VAP=@!097)L7W-V7W-E
M='!V`'!E<FQ?86QL;V,`4&5R;%]D;W5N=VEN9`!097)L7W-Y<U]T97)M`&)O
M;W1?1'EN84QO861E<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?;F5W6%-?9FQA
M9W,`<&5R;%]C;VYS=')U8W0`4&5R;%]S=E]S971P=FX`4&5R;%]A=E]F971C
M:`!P97)L7V1E<W1R=6-T`&5N=FER;VX`4&5R;%]M9U]S970`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]S869E<WES;6%L;&]C`%!E<FQ?;F5W4U9P=@!0
M3%]D;U]U;F1U;7``4$Q?;65M;W)Y7W=R87``4&5R;%]N97=84P!097)L7W-Y
M<U]I;FET,P!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?<W9?,G!V7V9L
M86=S`&QI8FTN<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.0!L:6)T
M:'(N<V\N,P!O<&5N`')E860`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!?
M7V5R<F]R`'!T:')E861?871F;W)K`&QI8F,N<V\N-P!?7W-T86-K7V-H:U]G
M=6%R9`!M96UC<'D`<F5A;&QO8P!?7W!R;V=N86UE`')E861L:6YK`%]?<W1D
M97)R<`!R;61I<@!M:V1I<@!S=')N8VUP`'-T<FQE;@!O<&5N9&ER`&QS965K
M`&%T97AI=`!A8V-E<W,`9V5T<&ED`&UE;6UO=F4`7U]S=&%C:U]C:&M?9F%I
M;`!S=')T;VL`8VQO<V5D:7(`<W1R;F-P>0!U;FQI;FL`;65M<V5T`%]I;FET
M7W1L<P!G971U:60`9G!R:6YT9@!S<')I;G1F`&UE;6-H<@!L<W1A=`!S=')S
M='(`<W1R8VUP`')E861D:7(`<W1R9'5P`&5X96-V<`!?961A=&$`7U]B<W-?
M<W1A<G0`7V5N9``O=7-R+VQO8V%L+VQI8B]P97)L-2\U+C$V+VUA8V@O0T]2
M10!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``>'-?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R
M7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`&UA:6X`1D)31%\Q+C```````@`!``$````"
M``$```````(``P```````0`!``$``0`!``````````$``0````(``@`!``(`
M`@`"``(````"`````@`"``(``P````(``@```````P```````@`"``(``@`"
M``$``@```````P````,``@`"``(``0`!`````@`#``(``@`!`````@`"``$`
M`@`"`````````````@`!``$``@````$``0`!`````@`"``(``@`!``$``0``
M``````````$``0#N`0``$````"````"P*'H'```#`(`$`````````0`!`#4"
M```0`````````+`H>@<```(`@`0```````"`Q&````````4````'````````
M``````"@Q&````````4```!&``````````````#@Q&````````4```!-````
M``````````#PQ&````````4```!.```````````````@Q6````````4```!:
M```````````````PPF````````<````!```````````````XPF````````<`
M```$``````````````!`PF````````<````%``````````````!(PF``````
M``<````(``````````````!0PF````````<````)``````````````!8PF``
M``````<````*``````````````!@PF````````<````+``````````````!H
MPF````````<````2``````````````!PPF````````<````3````````````
M``!XPF````````<````4``````````````"`PF````````<````7````````
M``````"(PF````````<````8``````````````"0PF````````<````9````
M``````````"8PF````````<````;``````````````"@PF````````<````<
M``````````````"HPF````````<````=``````````````"PPF````````<`
M```>``````````````"XPF````````<````?``````````````#`PF``````
M``<````@``````````````#(PF````````<````A``````````````#0PF``
M``````<````B``````````````#8PF````````<````C``````````````#@
MPF````````<````D``````````````#HPF````````<````E````````````
M``#PPF````````<````F``````````````#XPF````````<````G````````
M````````PV````````<````H```````````````(PV````````<````I````
M```````````0PV````````<````J```````````````8PV````````<````K
M```````````````@PV````````<````L```````````````HPV````````<`
M```M```````````````PPV````````<````N```````````````XPV``````
M``<````O``````````````!`PV````````<````P``````````````!(PV``
M``````<````Q``````````````!0PV````````<````R``````````````!8
MPV````````<````T``````````````!@PV````````<````U````````````
M``!HPV````````<````V``````````````!PPV````````<````W````````
M``````!XPV````````<````X``````````````"`PV````````<````Y````
M``````````"(PV````````<````Z``````````````"0PV````````<````[
M``````````````"8PV````````<````\``````````````"@PV````````<`
M```_``````````````"HPV````````<```!```````````````"PPV``````
M``<```!!``````````````"XPV````````<```!"``````````````#`PV``
M``````<```!#``````````````#(PV````````<```!%``````````````#0
MPV````````<```!'``````````````#8PV````````<```!)````````````
M``#@PV````````<```!*``````````````#HPV````````<```!+````````
M``````#PPV````````<```!,``````````````#XPV````````<```!/````
M````````````Q&````````<```!2```````````````(Q&````````<```!3
M```````````````0Q&````````<```!7```````````````8Q&````````<`
M``!8```````````````@Q&````````<```!9```````````````HQ&``````
M``<```!;```````````````PQ&````````<```!?```````````````XQ&``
M``````<```!@``````````````!(@^P(Z!\%``#H^CH``$B#Q`C#`/\U[J<@
M`/\E\*<@``\?0`#_)>ZG(`!H`````.G@_____R7FIR``:`$```#IT/____\E
MWJ<@`&@"````Z<#_____)=:G(`!H`P```.FP_____R7.IR``:`0```#IH/__
M__\EQJ<@`&@%````Z9#_____);ZG(`!H!@```.F`_____R6VIR``:`<```#I
M</____\EKJ<@`&@(````Z6#_____)::G(`!H"0```.E0_____R6>IR``:`H`
M``#I0/____\EEJ<@`&@+````Z3#_____)8ZG(`!H#````.D@_____R6&IR``
M:`T```#I$/____\E?J<@`&@.````Z0#_____)7:G(`!H#P```.GP_O___R5N
MIR``:!````#IX/[___\E9J<@`&@1````Z=#^____)5ZG(`!H$@```.G`_O__
M_R56IR``:!,```#IL/[___\E3J<@`&@4````Z:#^____)4:G(`!H%0```.F0
M_O___R4^IR``:!8```#I@/[___\E-J<@`&@7````Z7#^____)2ZG(`!H&```
M`.E@_O___R4FIR``:!D```#I4/[___\E'J<@`&@:````Z4#^____)1:G(`!H
M&P```.DP_O___R4.IR``:!P```#I(/[___\E!J<@`&@=````Z1#^____)?ZF
M(`!H'@```.D`_O___R7VIB``:!\```#I\/W___\E[J8@`&@@````Z>#]____
M)>:F(`!H(0```.G0_?___R7>IB``:"(```#IP/W___\EUJ8@`&@C````Z;#]
M____)<ZF(`!H)````.F@_?___R7&IB``:"4```#ID/W___\EOJ8@`&@F````
MZ8#]____);:F(`!H)P```.EP_?___R6NIB``:"@```#I8/W___\EIJ8@`&@I
M````Z5#]____)9ZF(`!H*@```.E`_?___R66IB``:"L```#I,/W___\ECJ8@
M`&@L````Z2#]____)8:F(`!H+0```.D0_?___R5^IB``:"X```#I`/W___\E
M=J8@`&@O````Z?#\____)6ZF(`!H,````.G@_/___R5FIB``:#$```#IT/S_
M__\E7J8@`&@R````Z<#\____)5:F(`!H,P```.FP_/___R5.IB``:#0```#I
MH/S___\E1J8@`&@U````Z9#\____)3ZF(`!H-@```.F`_/___R4VIB``:#<`
M``#I</S___\E+J8@`&@X````Z6#\____)2:F(`!H.0```.E0_/___R4>IB``
M:#H```#I0/S___\E%J8@`&@[````Z3#\____)0ZF(`!H/````.D@_/___R4&
MIB``:#T```#I$/S___\E_J4@`&@^````Z0#\____)?:E(`!H/P```.GP^___
M_R7NI2``:$````#IX/O___\EYJ4@`&A!````Z=#[__\`````54B)Y4%53(UO
M"$%44TB#[`B+'TACPX7;3(UDQQ!,B27\JB``?CI(BU<(2(72=#%(B16JI2``
M#[8"A,!T(TB#P@$\+TB+!9:E(`!(#T3"2(D%BZ4@``^V`DB#P@&$P'7AN"C`
M8`!(A<!T*TB)]^@:_/__OU150`#H$/S__^@W^___B=],B>),B>[H,B,``(G'
MZ-?^___H8OS__^O6D)"0D(`](:8@``!52(GE=!#K))!(@\`(2(D%-:4@`/_2
M2(L%+*4@`$B+$$B%TG7DQ@7UI2```<G##Q]$``!F#Q]$``!52(,]UZ`@``!(
MB>5T%K@`````2(7`=`R_(,!@`$F)P\E!_^/)PY"0D)"0D)"0D)`/M@](B?B$
MR70H2(L%_S<``$B-5P$/MC!(B?@/'T0``$`X\0^V"D@/1,)(@\(!A,EU[O/#
M9@\?1```9@\?1```059(C7<X055!5%5(B?U32('L"`(``$R-3"2(38V!@```
M`$R)STB+#DB#Q@A(B<I(B<A(P>((2,'@&"4```#_@>(``/\`2`G"2(G(2,'H
M""4`_P``2`G"2(G(2,'H&"7_````2`G"2(G(2,'I*$C!Z"!(B1=(P>`(2(G"
M2,'@$"4```#_@>(``/\`2`G"2(G(2,'I$"4`_P``2`G"2`G*2(E7"$B#QQ!,
M.<</A77___])C4EH28VQ:`(```\?1```2(L!2#-!V$@S0:A(,T&82(G"2`'`
M2,'J'T@)PH/B_TB)41A(@\$(2#GQ==1,BW4`2(M\)(A!O=R\&X](`WT@2(M-
M"$R+51!(BW483(GP3(GR38GQ2,'B!4C!Z!M)B<A("=!,B=))P>@"@^#_2"'*
M2<'I`DB-O`>9>8):2(G(2,'A'DCWT$D)R$@A\$&#X/](`W0DD$@)T$R)P@''
M3(GP3"'R2/?02(GY3"'02,'I&TP#5"282`G"2(GX2,'@!4B-M!:9>8):2(GZ
M2`G!3(GP2,'@'@'Q20G!2(GX2(G.08/A_TCWT$C![AM,(<I,(<!("=!(B<I-
MC90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(]]!)P>H"2,'G'DP#1"2@20GZ
M3"'(2(GW08/B_TC![QM,`TPDJ$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)
MQTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,`U0DL$PA
MPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"2/?0
M20GQ3"'`2(G.08/A_TC![AM,(<I("=!(B<I-C90"F7F"6DB)R$C!X`5,`T0D
MN$@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPD
MP$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"
M2/?020G(3"'02(GY08/@_TC!Z1M,`U0DR$PAPD@)T$B)^DV-C`&9>8):2(GX
M2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TPARDC!
M[AM,`T0DT$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)
MP>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPDV$PATD@)T$B)\DV-A`"9>8):
M2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!
MZ1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(P>8>2<'I
M`DCWT$D)\4B)SD&#X?],`U0DX$PAP$PARDC![AM,`T0DZ$@)T$B)RDV-E`*9
M>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B
M_TC![QM,`TPD\$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)
MR$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"
M6DB)^$C!X`5("<%(B?A$`<E)B?%(]]!)P>D"2,'F'DP#5"3X20GQ3"'`2(G.
M08/A_TC![AM,`P0D3"'*2`G02(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'6
M28GZ2,'G'DG!Z@)(]]!)B?-)"?I,(<A(B?=!@^+_2,'O&TP#3"0(3"'22`G0
M2(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,
M(=!(B?E!@^#_2,'I&TPAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4C!YAY)P>L"
M3`-4)!!("<%)"?-(B?A!@^/_1`')2/?03"':2(G.3"'`28GY2,'N&T@)T$C!
MYQY)P>D"38V4`IEY@EI(B<A,`T0D&$C!X`5)"?E(B<I("<9(B<A!@^'_2/?0
M3"'*1`'63"'82(GW28G*2`G02,'A'DC![QM-C80`F7F"6DB)\$G!Z@)(P>`%
M3`-<)"!)"<I("<=(B?!!@^+_2(GR2/?01`''3"'(28GP3"'22`G02,'F'DG!
MZ`)-C9P#F7F"6DD)\$B)^DB)^$&#X/],`TPD*$C!X`5(P>H;2`G"3(G`3#'0
M1`':3`-4)#!(,?A(B=%-C8P!H>O9;DB)T$C!Z1M(P>`%2`G!1`')28GY2,'G
M'DG!Z0)(B<Y)"?E(B==(P>X;08/A_TC![P),B<A,,<!,`T0D.$@QT$C!XAY-
MC90"H>O9;D@)UTB)R(/G_TC!X`5("<9(B?A$`=9,,<A,`TPD0$@QR$B)\DV-
MA`"AZ]EN2(GP2,'J&TC!X`5("<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](
MP>D;3(G`2#'X2`-\)$A(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>
M2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`-$)%!(,=!(C;P'H>O9;DB)R$C!
MX`5("<8!_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#3"182#'(
M38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I
M&TR)P$@Q^$@#?"1@2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!
MZ0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#1"1H2#'02(V\!Z'KV6Y(B<A(P>`%
M2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`TPD<$@QR$V-
MA`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,
MB<!(,?A(`WPD>$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"
M20GQ2(G.08/A_TC![AM,B<A,,<!,`X0D@````$@QT$B-O`>AZ]EN2(G(2,'@
M!4@)Q@'^2(G72,'B'DC![P)("==(B?*#Y_](B?A,,<A(P>H;3`.,)(@```!(
M,<A-C80`H>O9;DB)\$C!X`5("<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](
MP>D;3(G`2#'X2`.\))````!(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(
MP>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`3`.$))@```!(,=!(C;P'H>O9
M;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#
MC"2@````2#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))B=))
M"<A(B=%)P>H"08/@_TC!Z1M,B<!(,?A(`[PDJ````$@Q\$V-C`&AZ]EN2(G0
M2,'@!4@)P40!R4F)\4C!YAY)P>D"28G,20GQ2(G.08/A_TC![AM,B<A,,<!,
M`X0DL````$@QT$C!XAY(C;P'H>O9;DD)TDB)R$&#XO](P>`%2`G&3(G0`?Y,
M,<A)P>P"2#'(2,'A'DB)\DV-A`"AZ]EN20G,2(GP08/D_TP#C"2X````2,'@
M!4C!ZAM(B?-(BXPDR````$@)PDR)X$C!ZP),,=!$`<),`Y0DP````$@Q\$C!
MYAY(B==-C8P!H>O9;D@)\TB)T(/C_TC!X`5(P>\;2`G'2(G828G33#'@1`'/
M2<'K`D@QT$C!XAY)B?A-C90"H>O9;DD)TTB)^$&#X_](P>`%2<'H&TD)P$P!
MZ4R)V$4!T$R)VDP!X4@)V$@AVDR)QD@A^$F)^4C![AM("=!(P><>2<'I`D@!
MP4R)P$D)^4C!X`5!@^'_38G"2`G&3(G(3(G*`<Y(BXPDT````$P)V$PAVDPA
MP$B)]T@)T$C![QM)P>`>3`'I2<'J`D&\UL%BRD@!V4T)PD@!P4B)\$&#XO](
MP>`%3(G22`G'3(G0`<](BXPDV````$P)R$@A\$F)^$P!Z4P!V4PARDF)\T@)
MT$C!YAY)P>@;2`'!2(GX2<'K`DC!X`5)"?-)"<!!@^/_00'(2(N,).````!,
MB=A,"=!,B=I,B<9,(=)((?A(P>X;3`'I2`G03`')28GY2,'G'D@!P4R)P$G!
MZ0)(P>`%20GY2`G&08/A_P'.2(N,).@```!,B<A,"=A,B<I(B?=,(=I,(<!,
M`>E("=!,`=%-B<)(`<%(B?!(P>\;2,'@!4G!X!Y)P>H"2`G'30G"`<]!@^+_
M2(N,)/````!,B=!,B=))B?A,"<A,(<I)P>@;3`'I2"'P2`G03`'928GS2`'!
M2(GX2,'F'DC!X`5)P>L"20G`20GS00'(08/C_TB+C"3X````3(G83(G:3(G&
M3`G03"'22,'N&TP!Z4@A^$@)T$P!R4F)^4@!P4R)P$C!X`5("<8!SDC!YQY)
MP>D"20GY2(N,)``!``!(B?=!@^'_2,'O&TR)R$R)RDP)V$PAVDP!Z4PAP$P!
MT4V)PD@)T$G!X!Y)P>H"2`'!2(GP30G"2,'@!4&#XO]("<=,B=!,B=(!STB+
MC"0(`0``3`G(3"'*2"'P28GX2`G02<'H&TP!Z4P!V4F)\TC!YAY(`<%(B?A)
MP>L"2,'@!4D)P$$!R$D)\TB+C"00`0``08/C_TR)QDR)V$R)VDC![AM,"=!,
M(=),`>E((?A,`<E)B?E("=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_2`G&
M3(G(3(G*`<Y(BXPD&`$``$P)V$PAVDPAP$B)]T@)T$C![QM,`>E,`=%-B<))
MP>`>2`'!2(GP2<'J`DC!X`5-"<)("<=!@^+_`<](BXPD(`$``$R)T$R)TDF)
M^$P!Z4P!V4P)R$PARD@A\$F)\TG!Z!M("=!(P>8>2<'K`D@!P4B)^$D)\TC!
MX`5!@^/_20G`3(G83(G:00'(2(N,)"@!``!,"=!,(=)((?A,B<9("=!(P>X;
M3`'I3`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY2`G&08/A_P'.2(N,)#`!
M``!,B<A,"=A,B<I(B?=,(<!,`>E,`=%,(=I-B<)("=!)P>`>2,'O&T@!P4B)
M\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,)#@!``!,B=!,"<A,B=))B?A,(<I(
M(?!)P>@;3`'I2`G03`'928GS2,'F'D@!P4B)^$G!ZP)(P>`%20GS20G`08/C
M_T$!R$B+C"1``0``3(G83`G03(G:3(G&3"'22"'X3`'I2`G03`')28GY2`'!
M3(G`2,'N&TC!X`5(P><>2<'I`D@)QDD)^0'.08/A_TB+C"1(`0``3(G(3(G*
M2(GW3`G83"':2,'O&TP!Z4PAP$@)T$P!T4V)PD@!P4B)\$G!X!Y(P>`%2<'J
M`D@)QTT)P@'/08/B_TB+C"10`0``3(G03(G228GX3`G(3"'*2<'H&TP!Z4@A
M\$@)T$P!V4F)\T@!P4B)^$C!X`5)"<!!`<A(P>8>2<'K`DD)\TB+C"18`0``
M3(G&08/C_TC![AM,B=A,B=I,`>E,"=!,(=),`<E((?A)B?E("=!(P><>2<'I
M`D@!P4D)^4R)P$&#X?],`ZPD8`$``$C!X`5("<9,B<A,B<I,"=A,(=H!SDPA
MP$B)]T@)T$T!U4C![QM)`<5(B?!-B<)(P>`%2<'@'DG!Z@)("<=(BY0D:`$`
M`$0![TT)PDF)\$&#XO](B?E)P>@"3(G03`'B2,'I&TPQR$P!VD@Q\$C!YAY(
M`<)(B?A)"?!(P>`%08/@_T@)P4R)P`'12(N4)'`!``!,,=!(,?A(B<Y(P>X;
M3`'B3`'*28GY2,'G'D@!PDB)R$G!Z0)(P>`%20GY2`G&08/A_P'62(N4)'@!
M``!,B<A,,<!(B?=(,<A,`>),`=))B<I(`<)(B?!(P>\;2,'@!4C!X1Y)P>H"
M2`G'20G*`==(BY0D@`$``$&#XO],B=!(B?E,,<A(P>D;3`'B2#'P3`'"28GP
M2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)(@!``!,B<!,,=!(
MB<Y(,?A(P>X;3`'B3`'*28GY2,'G'D@!PDB)R$G!Z0)(P>`%20GY2`G&`=9(
MBY0DD`$``$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)
M\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4))@!``!,B=!,,<A(B?E(,?!(P>D;
M3`'B3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)*`!
M``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY2`'"2(G(2,'@!4C!YQY)P>D"
M2`G&20GY`=9(BY0DJ`$``$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*
M2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4)+`!``!,B=!,,<A(
MB?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!08/@
M_P'12(N4)+@!``!,B<!(B<Y,`>),,=!(P>X;2#'X3`'*28GY2`'"2(G(2,'G
M'DC!X`5)P>D"2`G&20GY`=9(BY0DP`$``$&#X?],B<A(B?=,,<!(P>\;3`'B
M2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4),@!
M``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2`'"2(GX2,'@!4@)P4C!YAY)
MP>@"`=%)"?!(BY0DT`$``$&#X/](B<Y,B<!(P>X;3`'B3#'02#'X3`'*28GY
M2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(BY0DV`$``$&#X?],B<A(B?=)
MB?-,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'
M08/B_P'72(N4).`!``!,B=!(B?E(B?M,`>),`<),,<A(P>D;2#'P2<'K`DC!
MYAY(`<)(B?A)"?-(P>`%08/C_TC!ZP)("<%,B=@!T4B+E"3H`0``3#'02#'X
M28G(2,'G'DG!Z!M("?M,`>*#X_],`<I)B<E(`<)(B<A(P>`%20G`2(G800'0
M2(N4)/`!``!,,=A(,<A,B<=,B<9(P>\;3`'B3`'22`'"3(G`2,'@!4@)QP'7
M2,'A'DG!Z0))"<E(BY0D^`$``$C![@)!@^'_2(GY3(G(2,'I&TP!XD@QV$P#
MI"0``@``3#'`3`':2<'@'D@!PDP)QDB)^$C!X`6#YO]("<%(B?!)`=Q,,<@!
MT4@Q^$B)RDD!Q$B)R$C!X@5(P>@;2`G01`'@1`'P2(E%`$B)^$C!YQY(P>@"
M`TT(2`GX`T40`W481`--($B)30A(B4402(EU&$R)32!(@<0(`@``6UU!7$%=
M05[#3(ED).!,B7PD^$F)_$B)7"302(EL)-A)B?=,B6PDZ$R)="3P2(/L.$B%
M_W4E,<!(BUPD"$B+;"003(MD)!A,BVPD($R+="0H3(M\)#!(@\0XPTR+-8>3
M(`!-A?9TSP^V!X3`=00QP.L7/#U(B?IT]4B#P@$/M@*$P'5%B=!$*>!)BRY(
MA>UTI4QCZ$R)\V:03(GJ3(GF2(GOZ$[F__^%P'4*28U$+0"`.#UT&DB+:PA(
M@\,(2(7M==?I;____V:0/#UUK.NU3"GS2(/``4C!^P-!B1_I5O___P\?@```
M``!54TB)^TB#[!A(C6PD%&:0,<!(B>Y(B=_H`____TB%P'0F2&-$)!1(C13%
M`````$@#%<J2(`!(@\((2(L"2(7`2(E"^'7PZ\A(@\086UW#D$B#[!@QP$B-
M="04Z,#^__](@\08PP\?1```9@\?1```2(/L"(,]98T@`/]T"XL%78T@`$B#
MQ`C#,<"_:%5``.B\____2(7`=`</M@"$P'43,<")!3B-(`"+!3*-(`!(@\0(
MPSPP#Y7`#[;`Z^4/'P!(@^P(BSTVC2``Z(WE__^^_____TB)Q^@0Y/__BST>
MC2``Z'7E__\QTDB)Q[Z`-T``2(/$".G"YO__9@\?1```05132(/L"(L]\XP@
M`.A*Y?__BSWHC"``2(N`(`(``$R+8`CH-.7__XL]THP@``^VF/P#``#H(N7_
M_TB+0`B#XW\/MT`@9B7_`<'@!PG89D&)1"0"BSVFC"``Z/WD__](BX`@`@``
MBSV4C"``2(M8".CGY/__,=*^`5=``$B)Q^BXY?__2(E#*(L]<HP@`.C)Y/__
MBSUGC"``2(N`(`(``$B+6`CHL^3__TB+@+@%``!(B4,PBSU&C"``Z)WD__^+
M/3N,(`!(BX`@`@``2(M8".B'Y/__,=)(@[@@"@```'09BST9C"``Z'#D__](
MBX`@"@``2(N0J````$B)4SB+/?R+(`#H4^3__TB+@"`"``!(BT`(2,=`0```
M``"+/=Z+(`#H->3__TB+@"`"``!(BT`(2,=`(`````"+/<"+(`#H%^3__XL]
MM8L@`$B+@"`"``!(BU@(Z`'D__](BX`P`@``2(E#2$B#Q`A;05S#9I!,B60D
MZ$B)7"3828G\2(EL).!,B6PD\$R)="3X2('LJ````$B%_W0%@#\`=3-(BYPD
M@````$B+K"2(````3(ND))````!,BZPDF````$R+M"2@````2('$J````,,/
M'P#H]^/__TB%P$B)Q73`#Q\`2(GOZ,3A__](A<`/A*$```!(C5@(OW-50`"Y
M`@```/Q(B=[SIG39OW)50`"Y`P```$B)WO.F=,A,B>?H/.+__TB)WTF)Q>@Q
MXO__08U$!0)(8_CHA.#__TB)V4B)QTF)Q4R)XKYU54``,<#HS.'__TB)YDR)
M[^AAX?__@\`!=!$/MT0D""4`\```/0!```!T-DR)[^@CX?__3(GOZ-OC__](
MB>_H(^'__TB%P`^%7____TB)[^@"Y/__3(GGZ%KB___I]O[__TR)[^C!_O__
MD.O'#Q^```````\?@`````!32(G[BSTVBB``Z(WB__](C;"8````2(G?Z.[A
M__^%P'0$6S'`PXL]%(H@`.AKXO__#[>`H````"4`\```/0!```!T'HL]]HD@
M`.A-XO__#[>`H````"4`\```/0"@``!UP$B)W[X"````Z#WB__];A<`/E,`/
MML###Q^``````$B)7"3H2(EL)/!,B60D^$B![#@(``!(C9PD$`0``$B+!;N)
M(`!(B80D&`@``#'`Z)CB__^Y%5=``(G"OGM50``QP$B)W^B2X/__A<!Y-C'M
M2(N4)!@(``!(,Q6!B2``2(GH=6!(BYPD(`@``$B+K"0H"```3(ND)#`(``!(
M@<0X"```PTB)W[H`!```2(GFZ"C?__^%P(G#>+2->`%(8__HU][__TB%P'2D
M2&/;2(G%2(GF2(G:2(G'Z-[A___&!"L`ZXSH@^'__P\?@`````#I*____P\?
M1```9@\?1```05<QP$%628G^055!5%5(B?532(/L&(`^/0^4P$@!Q4B)[^@5
MX/__2(UT)!1!B<=,B?<QP.C'^?__2(7`2(G#=#=(B<?H\]___T2)^D@YT`^"
MO`````^V10!(@\4!B`-(@\,!A,!U[DB#Q!@QP%M=05Q!74%>05_#2(L]88T@
M`$4QY+@0````2(,_`'0?2(GZ2(M""$&#Q`%(@\((2(7`=>]!C40D`DB82,'@
M`XL5[H@@`(72#X40`0``2(G'QP79B"```0```.C0W?__2(7`28G%#X09`0``
M26/$2(LU_HP@`$R)[TB-',4`````2(G:Z'?A__],B2WDC"``2(L%W8P@`$C'
M1`,(`````$2)9"0400^V%DR)\(32#X6(````BUPD%$4I]T&-?`<"2,'C`T@#
M':F,(`#H8-W__TB%P$B)`P^$J0```(M4)!1(BP6-C"``2(L4T$$/M@:$P(@"
M="4\/70A3(GWZPYF#Q]$``!(@\<!/#UT#@^V1P%(@\(!A,"(`G7JQ@(]#Q^`
M``````^V10!(@\4!B$(!2(/"`83`=>WIO_[__X#Z/0^$;____TB#P`$/M@B$
MR0^$8/___X#Y/77LZ5;___](B<8/'P#HM]___TB%P$B)!0&,(`!T$$ECQ$B-
M',4`````Z0O___](@\08N/____];74%<05U!7D%?PP\?1```9@\?1```05=!
M5DF)_D%5051!O)%50`!54TB#[$A,BSVZ&0``28GE2,<$))%50`!(QT0D"(=5
M0`!(QT0D$)150`!(QT0D&(I50`!(QT0D((]50`!(QT0D**%50`!(QT0D,```
M``#K'DR)]DR)YS'`Z(+]__]-BV4(28/%"$V%Y`^$B0```#'`3(GGZ)?X__](
MA<!(B<5TT(`X`'3+3(GV2(G'Z"O?__](A<!UR$R)]^A^W?__3(G_2(G#Z'/=
M__](C5P#`4B)[^AFW?__2(T\`^B]V___28GH2(G'2(G#3(GY3(GROKQ60``Q
MP.@"W?__3(GG,<!(B=[H^?S__TV+90A)@\4(387D#X5W____2(/$2%M=05Q!
M74%>05_#9@\?A```````2(/L.+^L54``2(L%P(4@`$B)1"0H,<!(BP5J&```
M2(D$)$B+!6<8``!(B40D"$B+!6,8``!(B40D$$B+!5\8``!(B40D&`^W!5L8
M``!FB40D(#'`Z%?W__\QP+^U54``Z$OW__\QP+^]54``Z#_W__\QP+_&54``
MZ#/W__\QP+_-54``Z"?W__\QP+_=54``Z!OW__\QP+_I54``Z`_W__\QP+]H
M54``Z`/W__\QP+_R54``Z/?V__\QP+_\54``Z.OV__\QP+\&5D``Z-_V__\Q
MP+\35D``Z-/V__\QP+\<5D``Z,?V__\QP+\G5D``Z`OW__](A<!T#TB)QK_R
M54``,<#HQ_O__S'`OSA60`#HZ_;__TB%P'0/2(G&OTI60``QP.BG^___,<"_
M559``.C+]O__2(7`=#9(B<:_Z55``#'`Z(?[__\QP+Z!5D``O\U50`#H=OO_
M_TB+1"0H2#,%:H0@`'512(/$.,,/'P`QP+]E5D``Z(3V__](A<!T$4B)QK]H
M54``,<#H0/O__^NW2(UT)!&_=E9``+D*````_/.F=:-(C70D&[]H54``,<#H
M&?O__^N0Z'[<__]FD$B#[`CHP]O__XG'Z+S9__\QTDB%P'0#2(L02(G02(/$
M",,/'X``````#Q^``````%532(G[2(/L"$B%_W0(#[8O0(3M=1!(@\0(OW-5
M0`!;7>F6VO__Z/':__](`=A(C5#_2#G3#X.>````2(L]?A8```^V0/\/MC=`
M./!T">LJ#[8*.,%U9DB#Z@%(.=-FD'+N2#G:=2E`.B]TJDB#Q`A;7>E%VO__
M#[8"0#C&=.-(@^H!2#G3<N_KV&8/'T0``$B#Z@%(.=-S"0^V`CH'9I!T[D@I
MVC')2(U"`D@]``0``'8.2(/$"$B)R%M=PXG(Z[E(@\(!2(G>OV#%8`#H:MO_
M_[E@Q6``Z]I(BSW@%0``ZX`/'X``````#Q^``````$B)7"3P2(EL)/A(@^P8
M2(G[Z/K^__](B<?HHMW__TB)Q3'`Z!CU__^%P'0*2(7;=`6`.P!U#TB+7"0(
M2(ML)!!(@\08P[Z#5D``2(GOZ'K;__](.<5UWTB)WTB+;"002(M<)`A(@\08
MZ=/V__\/'P!32(/L((E\)!Q(B70D$$B-?"0<2(E4)`A(C70D$$B-5"0(Z+7;
M__^ZG!I``+_\&T``2(G6Z&/:__^`/8""(```=2_HY=C__TB%P$B)QTB)!>R&
M(``/A)@!``#HK=G__XL]^X$@`.A2VO__QH#_`P```(L]Z8$@`.A`VO__@(AS
M!````HL]UX$@`.@NVO__@(AS!````8M$)!R#P`5(8\A(A<D/B!P!``#R2`\J
MP?(/6`6;<0``9@\N!9MQ```/AQX!``!(C3S-`````.B\VO__2(MT)!!(B<%(
MB05YAB``3(U)^$B+!DC'00B(5D``2(D!2(L%0($@`$C'01B+5D``2(E!$$2+
M1"0<QP4]AB``!````$&#^`%^(TR-2?B_`0```+H(````2(L$%H/'`4B)1`H8
M2(/""$$Y^'_K08U`!+[05$``13'`2)A)QP3!`````(M4)!Q(BSWCA2``@\(#
MZ.?6__^%P(G#=$E(BSW.A2``Z#79__\QP+_=54``Z"WS__](A<!T&4B+/;&%
M(`#HF-;__^@#V/__B=A(@\0@6\-(BSV@A2``2(7_=$WHWOW__^O42(L]A84@
M`.C,UO__B</KITB)R$B)RDC1Z(/B`4@)T/)(#RK`\@]8P.G,_O__OO#$8`"_
MA%5``#'`Z%K9__]`MP'HLMG__[_I54``Z*SR__](A<!(B<=(B04WA2``=9KI
M</___P\?A```````05=!5D%5051)B?R_Z55``%532(GS2('L*`0``$B+!3V`
M(`!(B80D&`0``#'`Z%[R__](BRT'$P``3(GG28G%2(GNZ/78__](A<!T.4R)
MYK\&5D``,<#H!??__TB+E"08!```2#,5]G\@`$R)X`^%3@$``$B!Q"@$``!;
M74%<05U!7D%?PTR)Y^@/U___3(L]M!(``$B)WT&)QDR)_N@:UO__2(7`2(G#
M=*)!@\8!1(ET)`Q,C70D$(`[`+AS54``2`]$V$V%[7032(G>3(GOZ!C9__^%
MP`^$G````$B)W^BXUO__B<%(F`^V1`/_.D4`=2&-0?](F$B-%!@/'T0```^V
M0O_&`@"#Z0%(@^H!.D4`=.V+1"0,`<@]_P,```^/*/___TV)X$B)Z4B)VKZ\
M5D``3(GW,<#H(-;__XL]_GX@`.A5U___2(VPF````$R)]^BFU?__A<!U'HL]
MX'X@`.@WU___#[>`H````"4`\```/0"```!T&S'_3(G^Z#K5__](A<!(B<,/
MA2K____IN?[__[X!````3(GWZ`S7__^%P'743(GVOP960`#HK_7__TR)]^B#
MU?__28G$Z9K^___H!M?__V8N#Q^$``````!!5TF)_[_I54``059!54%455-(
M@>QH@0``2(L%<'X@`$B)A"18@0``,<!(QT0D4(Y60`!(QT0D6)-60`!(QT0D
M8`````#H=O#__TB%P$B)PW0)@#@`#X6!`@``,<!(C6PD4.@9^O__2(7`2(G#
M#X3(`0``2(G?Z%'5__](C7P``>BGT___@#L`28G%=")(B<4/MA-(B>\QP+ZC
M5D``2(/#`4B#Q0+HXM3__X`[`'7A2(UL)""_2E9``$C'1"0@2E9``$C'1"0H
M0U9``$C'1"0PJ%9``$C'1"0X8%9``$C'1"1`L%9``$C'1"1(`````.L12(M]
M"$B#Q0A(A?\/A&4!```QP.BW[___2(7`2(G#=."`.`!TVTB)Q^@2\___A<!T
MSTB)W^A"U/__2(7`28G$#X0T`0``3(GGZ([4__],B>](B</H@]3__XV$`P0$
M``!,8_!,B??HT=+__TB+%0X0``!(B<=(B<5-B>E!N(-60`"^NE9``#'`2(G1
M2(E4)!!,B>+H!-3__[[``0``2(GOZ,?4__^#P`$/A%8!``"+/<Q\(`#H(]7_
M_TB-L)@```!(B>_HA-3__X7`=2*+/:Y\(`#H!=7__P^W@*`````E`/```#T`
M0```#X10`0``28L72(L]*'T@`$B)Z;[05T``,<`QV^B#T___2(N4)%B!``!(
M,Q6(?"``2(G8#X6)`@``2('$:($``%M=05Q!74%>05_#2(G'Z$'3__](B<-(
M@\4(2(7;#X4X_O__2(M]`$B%_P^$2`(``#'`Z''N__](A<!TVH`X`'7*2(/%
M"$B%VW39Z0S^__]%,>2`/3,.````2,=$)'"T5D``N[160`!(QT0D>'-50`!(
MQX0D@`````````!(C6PD<'4HZ9;^__]-A>0/A8W^__](BUT(2(7;#X2`_O__
M2(/%"(`[``^$<_[__TB)W^AE\?__A<!TT4B)W^B5TO__28G$Z\1(B<?HO/3_
M_TB)W^B`TO__2(G#Z07____H,]3__X,X$0\?0``/A)C^___H(=3__TF+%T2+
M`$B)Z4B+/?5[(`"^D%=``#'`,=OH4]+__^G+_O__BST\>R``Z)/3__^+F*0`
M``#H"-/__SG##X62_O__BST>>R``Z'73__\/MX"@````)?\!```]P`$```^%
M</[__TR)]^BVT/__OXI50`!(B<,QP.@[[?__2(7`2(G'#X2/`0``Z-;1__])
MBS](B<;HC_K__TB%P$F)Q0^$<P$``$R)[^@7TO__@_@#08G`#X_D````,<#H
M&.W__X7`=18Q]DR)[^BFT/__A<")1"0<#X5&`0``OH%60`"_:%5``#'`Z)WQ
M___HA-/__TB+3"0008G`0;D!5T``2(GJOMQ60`!(B=\QP$4QY.AQT?__ZSCH
M"M/__X,X$75`Z%#3__](BTPD$$&#Q`%!B<!%B>%(B>J^ZE9``$B)WS'`2,<$
M)`%70`#H-]'__[[``0``2(G?Z/K1__^#P`%TMDB)[^A=T___2(G>O^E50``Q
MP.@2\?__2(G?Z!KS___I;OW__P\?1```NYQ60`#IV?O__V8/'T0``.A7TO__
M2)B_PU9``$F-=`7\N`4```#\2(G!\Z8/A?_^__]!@_@$=!E!C4#\2(M4)!!(
MF$$/MD0%_SH"#X7@_O__38MG"$V%Y`^$T_[__TR)Y^C6T/__2(/X`P^&P?[_
M_TF-=`3\O\A60`"Y!0```/SSIDT/1.SIIO[__P\?1```38LOZ87^__^Z`@``
M`$C'QN[___^)Q^B!T/__BWPD'$B-M"20````N@8```#HJ]#__X"\))``````
M=0Z`O"21````0P^$)P0``(M\)!PQ]C'23(VT))"```#H/M#__[^)J\WOOO[<
MNIBY\.'2PTC'A"20@````2-%9TB)O"28@```28/&.$B)M"2@@```2,>$)*B`
M``!V5#(02(F,)+"```!(QX0DN(````````!(QX0DP(````````#'A"0(@0``
M`````(M\)!Q(C;0DD````+H`@```Z`+0__^%P$&)Q0^..`$``$B+C"2X@```
M26/52(N$),"```!,C:0DD````(TTT4@YSDB)M"2X@```2(/0`$C!ZAU(B80D
MP(```$@!E"3`@```BY0D"($``(72=&7I@0```$F+!"1(C;PDD(```$&#[4!(
MB80DR(```$F+1"0(28E&"$F+1"0028E&$$F+1"0828E&&$F+1"0@28E&($F+
M1"0H28E&*$F+1"0P28E&,$F+1"0X28/$0$F)1CCHZM+__T&#_3]_FDECU4R)
MYDR)]^B"T/__1(FL)`B!``#I#?___[A`````2&/Z2(VT))`````IT$F-/#Y!
M.<5!B<1%#T[E36/\3(GZZ$K0__]$B>`#A"0(@0``@_A`B80D"($```^%R/[_
M_TB-C"20````12GE2(V\))"```!-C20/Z&C2___I>?___XM\)!SH5L[__TR+
MI"2X@```3(NL),"```!,B>!(P>@#@^`_2&/0@\`!@_@XQH04R(```(`/CJ8"
M``!(8_BZ0````#'V*<)(C;P\R(```$ACTNCYS___2(V\))"```#H`-+__TB-
MO"20@```N0<````QP/Q(@\<X\TBK3(GH2(V\))"```!$B*PD`X$``$C!Z!A$
MB*0D!X$``$R-M"00@0``B(0D`($``$R)Z$R-O"1`@0``2,'H$(B$)`&!``!,
MB>A-B?5(P>@(B(0D`H$``$R)X$C!Z!B(A"0$@0``3(G@2,'H$(B$)`6!``!,
MB>!%,>1(P>@(B(0D!H$``.ABT?__2(N4))"```!(B="(E"1#@0``2,'H&(B$
M)$"!``!(B=!(P>@0B(0D08$``$B)T$B+E"28@```2,'H"(B$)$*!``!(B="(
ME"1'@0``2,'H&(B$)$2!``!(B=!(P>@0B(0D18$``$B)T$B+E"2@@```2,'H
M"(B$)$:!``!(B="(E"1+@0``2,'H&(B$)$B!``!(B=!(P>@0B(0D28$``$B)
MT$B+E"2H@```2,'H"(B$)$J!``!(B="(E"1/@0``2,'H&(B$)$R!``!(B=!(
MP>@0B(0D38$``$B)T$B+E"2P@```2,'H"(B$)$Z!``!(B="(E"13@0``2,'H
M&(B$)%"!``!(B=!(P>@0B(0D48$``$B)T$C!Z`B(A"12@0``0P^V%#Q,B>\Q
MP+ZC5D``28/$`4F#Q0+H%<S__TF#_!1UWD&Y`5=``$V)\,:$)#B!````ZW&`
MO"22````00^%R_O__X"\)),```!##X6]^___@+PDE````$@/A:_[__^`O"25
M````10^%H?O__XM\)!RZ`@```$C'QL;____HW\O__XM\)!Q(C;0DD````+HI
M````Z`G,__],C80DD````$&Y`5=``$B+3"002(GJOLU60`!(B=\QP.ATR___
MZ4KZ__^Z.````$AC^#'V*<)(C;P\R(```$ACTNA3S?__Z7G]__]FD$%6055!
M5%532('L$`0``(L]&W0@`$B+!31T(`!(B80D"`0``#'`Z&',__^_S55``,:`
M_0,```$QP.A"YO__2(7`=`F`.#$/A'H"```QP&:0Z"ON__^+/=5S(`#H+,S_
M_[D+````2(G'N@$```"^^U9``.@%RO__2(7`#X2J````13'D@SV6>"```4B+
M0!!,BV@H#XZ`````O0@```#K+I!(BW,02(L%?7@@`$B+/"CH*,W__X7`=6!!
M@\0!2(/%"$&-1"0!.055>"``?DN+/5US(`#HM,O__S')2(G'1(GB3(GNZ'3+
M__](A<!T*TB+&/9##01UJHL]-',@`.B+R___2(G>2(G'N0(````QTNCIS/__
M2(G&ZXR+%0)X(`"-0O]$.>`/A&8!``"+/0!S(`#H5\O__[D$````2(G'N@$`
M``"^`%=``.@PR?__2(7`2(G%=#-(BT`0BSW2<B``2(L8Z";+__^Z`E=``$B)
MQTB)WN@6R?__2(M%$$B+&/9##D`/A4X!``"+/:-R(`#H^LK__[D$````2(G'
MN@$```"^)59``.C3R/__2(7`28G$=#DQP+\&5D``Z,/D__](A<!(B<4/A$T!
M``!)BT0D$(L]7'(@`$B+&.BPRO__2(GJ2(G'2(G>Z*+(__^+/4!R(`#HE\K_
M_\:`_0,```"+/2YR(`#HA<K__[_I54``2,>`B`8````````QP.ABY/__2(7`
M2(D%\'8@``^$P@```+[``0``2(G'Z.')__^%P'4E2(N$)`@$``!(,P4"<B``
M#X5@`0``2('$$`0``%M=05Q!74%>PX/X$736@_C_=-&)P4B+!;%V(`!(BQ6:
M=B``OWA80`!(BS`QP.B/RO__#Q\`@^H!#XZ1_O__NP$```!FD(L]BG$@`(/#
M`>C>R?__3(GN2(G'Z+/'__\Y'6%V(`!_W^ED_O__@'@!``^$A?W__^EW_?__
MBSU5<2``Z*S)__](B=Y(B<?HX<G__^F7_O__2(L],78@`.C$\O__2(7`2(D%
M$G8@``^%K0```+\H6$``Z`;*__](BP4+=B``BST-<2``3(LP28M$)!!,BRCH
M6<G__[K_`P``2(GFOP=70`#HY\;__X7`B<)^1H/J`4ACVH`\'`!U6(72?C9(
MB=J^+P```$B)Y^B!R/__2(7`="&+/;IP(`#H$<G__TB)V4B)QTB)XDR)[NC`
MR/__Z5G^__^+/9EP(`#H\,C__TR)\DB)QTR)[NCBQO__Z3O^__](8]CKI^@#
MR?__28M$)!!(BRUC=2``2(L8]D,-!'0[2(M[$$B)[NCBQO__B<5)BT0D$$B+
M&/9##01T04B+0Q!(B<)(BP4P=2``B>F_4%A``$B+,#'`Z!/)__^+/2%P(`#H
M>,C__[D"````2(G',=)(B=[HULG__TB)Q^NGBSW_;R``Z%;(__^Y`@```$B)
MQS'22(G>Z+3)___KI&8/'T0``$B#[`B+/=9O(`#H+<C__[D:5T``2(G'NNP;
M0`"^)%=``$B#Q`CI(LG__V8/'T0``$B#[`B+/:9O(`#H_<?__TB)Q^BY____
MBSV3;R``Z.K'__]!N`%70`!(B<=%,<E,B<&Z4%!``+Y`5T``2(/$".D(Q___
MD)"0D)"0D)"0D)"054B)Y5-(@^P(2(L%T&H@`$B#^/]T%3';_]!(BX/XOV``
M2(/K"$B#^/]U[4B#Q`A;R<.0D$B#[`CHH\G__TB#Q`C#````````4$%27T-,
M14%.`"XN`"5S+R5S`"]P<F]C+R5I+R5S`$Q)0E!!5$@`1%E,1%],24)205)9
M7U!!5$@`4TA,24)?4$%42`!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%
M4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%35``4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?4%)/1TY!344`4$%27T%21T,`4$%27T%2
M1U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]4
M35!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,
M14%./0`Q`'!A<BT`+64`+2T`55-%4@!54T523D%-10!365-414T`)3`R>`!4
M14U01$E2`%1-4``O=&UP+P`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P
M97)L`"]P<F]C+V-U<G!R;V,O9FEL90!P97)L>'-I+F,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`#H``%]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````"X5D```````%57
M0```````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0``````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@
M*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````",A+W5S
M<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU
M<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@
M=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S
M96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U
M=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@
M(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R
M86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@
M<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI
M;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T
M>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U
M;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U
M=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O
M=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@
M;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$
M;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N
M="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN
M9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@
M("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!5
M3DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@
M+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B([
M"B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@
M("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^
M)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M
M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^
M9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%
M3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`
M05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!
M4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L
M<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.
M5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@
M9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C
M=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C
M=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T
M.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&
M2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL
M97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L
M(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T
M.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*
M"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@
M("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U
M;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@
M("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@
M("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA
M;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H
M)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA
M;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@
M("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@
M("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M
M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@
M("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F
M(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@
M("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@
M("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@
M(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@
M("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I
M<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO
M9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*
M"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D
M;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE
M+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@
M("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@
M)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@
M<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY
M("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@
M("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD
M("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A
M;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D
M(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*
M("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T
M:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/
M.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@
M("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L
M92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@
M("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]
M"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@
M9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N
M<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@
M("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@
M("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R
M"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@
M87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E
M=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O
M(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@
M9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T
M:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI
M9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`
M05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q
M("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@
M>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@
M("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@
M)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@
M>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@
M("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G
M*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@
M("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@
M("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@
M:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T
M.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U
M<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[
M>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@
M)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H
M+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M
M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S
M+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T
M(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@
M(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D
M<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*
M("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\
M4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D
M;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@
M("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@
M(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@
M("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L
M87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V
M86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@
M)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S
M970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@
M("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@
M)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO
M9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@
M4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M
M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@
M("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@
M("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@
M("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@
M("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@
M=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I
M;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O
M<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I
M=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O
M;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A
M;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M
M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI
M)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@
M("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@
M(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@
M("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@
M("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@
M>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C
M72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A
M;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*
M("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q
M*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@
M("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D
M9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@
M;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%
M*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@
M("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*
M("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@
M("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@
M("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.
M;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@
M("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F
M;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O
M<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#
M04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S
M93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70[
M"GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C
M86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!0
M05(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@
M(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E
M($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@
M("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@
M("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@
M("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@
M("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T
M7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN
M+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]
M?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@
M(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H
M.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q
M=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6([
M"B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97([
M"B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@
M("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E
M($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E
M<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U
M:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q
M=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U
M:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@
M(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@
M(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U
M=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A
M<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L
M:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS
M=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@
M('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@
M("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*
M("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@
M("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@
M("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B
M/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#([
M"B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@
M("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@
M('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F
M:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<[
M"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@
M("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T
M.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O
M<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD
M)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA
M<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP
M9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L
M("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C
M)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N
M;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@
M0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@
M(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D[
M"B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M
M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M
M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@
M?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*
M("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@
M:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@
M("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G
M;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@
M4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@
M("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R
M7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@
M("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1?
M?3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@
M("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@
M("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@
M;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#
M3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L
M=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R![
M"B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@
M("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@
M("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@
M("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@
M("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@
M<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*
M"B-L:6YE(#$P,3$*"E]?14Y$7U\*````````````````````P$,!&P,[U```
M`!D```#@:?__\````/!J__\8`0``,&O__S`!```@@?__8`$```""__^(`0``
M4(+__Z@!``!P@O__P`$``,""___8`0```(/___`!``!PA/__$`(``,"%__\P
M`@``0(;__T@"```0A___:`(``""'__^``@``,(G__[@"``!0BO__\`(``!",
M__\(`P``0(S__R`#```PC?__0`,``*"-__]8`P``P(___W@#``"0D?__L`,`
M`-";___H`P``(*#__Q@$``!0H/__,`0````````4``````````%Z4@`!>!`!
M`PP'")`!```D````'````&`>0`"<`````$$.$(8"0PT&0HT#2X,%C`0`````
M````%````$0```!P'T``-```````````````+````%P```"P'T``\!4```!"
M#A!&#AA"#B!!#BB&!8P$C0..`D0.,$<.N`2#!@``)````(P```"@-4``V0``
M``!*CP*,!5X.0(X#C02&!H,'`````````!P```"T````@#9``$\`````00X0
M00X8@P.&`D<.,```%````-0```#0-D``%0````!$#B``````%````.P```#P
M-D``30````!$#A``````%`````0!``!`-T``.@````!$#A``````'````!P!
M``"`-T``;@$```!"#A!!#AA$#B"#`XP"```<````/`$``/`X0`!"`0```$J#
M!HP$60ZP`8X"C0.&!10```!<`0``0#I``'D`````00X0@P(``!P```!T`0``
MP#I``,D`````5@[`$(P"A@.#!```````%````)0!``"0.T``!0``````````
M````-````*P!``"@.T``!0(```!"#A!$#AB.`X\"10X@0@XH00XPA@:,!8T$
M1`XX1`Y0@P<````````T````Y`$``+`]0``7`0```$(.$$(.&(X#CP)%#B!"
M#BB,!8T$1PXP00XX1`Z``8,'A@8``````!0````<`@``T#Y``+X!````1`Y`
M`````!0````T`@``D$!``"(`````1`X0`````!P```!,`@``P$!``.(`````
M00X000X8@P.&`D<.(```%````&P"``"P04``;0````!.#B"&`H,#'````(0"
M```@0D``&`(```!!#A!$#C"#`@`````````T````I`(``$!$0`#&`0```$(.
M$$(.&$(.($(.*(P%C02.`X\"20XP00XX@P>&!DH.X`@``````#0```#<`@``
M$$9``#X*````0@X0CP)*#AA"#B!"#BA!#C!!#CA'#J"#`H,'A@:,!8T$C@,`
M````+````!0#``!04$``2@0```!"#A!"#AA"#B!!#BA!#C!'#L`(@P:&!8P$
MC0..`@``%````$0#``"@5$``*@````!$#A``````%````%P#``#05$``1```
M``!$#A``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````,D!`````````0``````
M``#3`0````````$`````````X0$````````!`````````.X!`````````0``
M```````U`@````````\`````````90,````````,`````````!@:0```````
M#0````````!454````````0`````````,`)````````%`````````.`-0```
M````!@````````#(!$````````H`````````B00````````+`````````!@`
M````````%0````````````````````,`````````&,)@```````"````````
M`#`&````````%``````````'`````````!<`````````Z!-````````'````
M`````'`30```````"`````````!X``````````D`````````&`````````#^
M__]O`````#`30```````____;P`````"`````````/#__V\`````:A)`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````HP&````````````````````````````!"&D```````%(:0```
M````8AI```````!R&D```````((:0```````DAI```````"B&D```````+(:
M0```````PAI```````#2&D```````.(:0```````\AI````````"&T``````
M`!(;0```````(AM````````R&T```````$(;0```````4AM```````!B&T``
M`````'(;0```````@AM```````"2&T```````*(;0```````LAM```````#"
M&T```````-(;0```````XAM```````#R&T````````(<0```````$AQ`````
M```B'$```````#(<0```````0AQ```````!2'$```````&(<0```````<AQ`
M``````""'$```````)(<0```````HAQ```````"R'$```````,(<0```````
MTAQ```````#B'$```````/(<0````````AU````````2'4```````"(=0```
M````,AU```````!"'4```````%(=0```````8AU```````!R'4```````((=
M0```````DAU```````"B'4```````+(=0```````PAU```````#2'4``````
M`.(=0```````\AU````````"'D```````!(>0```````(AY````````R'D``
M`````$(>0```````4AY````````!5T``````````````````&,!@``````#`
M6$```````/____\`)$9R965"4T0Z(')E;&5A<V4O.2XQ+C`O;&EB+V-S=2]A
M;60V-"]C<G0Q+F,@,C$V,S,X(#(P,3`M,3(M,#D@,C$Z,S$Z,C%:(&1I;2`D
M`"1&<F5E0E-$.B!R96QE87-E+SDN,2XP+VQI8B]C<W4O8V]M;6]N+V-R=&)R
M86YD+F,@,C$W,S<U(#(P,3$M,#$M,3,@,C`Z-#0Z,S%:(&1I;2`D`$=#0SH@
M*$=.52D@-"XR+C$@,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&<F5E
M0E-$.B!R96QE87-E+SDN,2XP+VQI8B]C<W4O86UD-C0O8W)T:2Y3(#(Q-S$P
M-2`R,#$Q+3`Q+3`W(#$V.C`W.C4Q6B!K:6(@)```1T-#.B`H1TY5*2`T+C(N
M,2`R,#`W,#@S,2!P871C:&5D(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N
M,2`R,#`W,#@S,2!P871C:&5D(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N
M,2`R,#`W,#@S,2!P871C:&5D(%M&<F5E0E-$70``)$9R965"4T0Z(')E;&5A
M<V4O.2XQ+C`O;&EB+V-S=2]A;60V-"]C<G1N+E,@,C$W,3`U(#(P,3$M,#$M
M,#<@,38Z,#<Z-3%:(&MI8B`D```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!
M0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N
M9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M```````````````````````````````````+`````0````(```````````)`
M`````````@```````!4````````````````````!````````````````````
M$P````<````"`````````!@"0```````&`(````````8````````````````
M````!````````````````````"$````%`````@`````````P`D```````#`"
M````````F`(````````$``````````@`````````!``````````G````"P``
M``(`````````R`1```````#(!````````!@)````````!0````$````(````
M`````!@`````````+P````,````"`````````.`-0```````X`T```````")
M!````````````````````0```````````````````#<```#___]O`@``````
M``!J$D```````&H2````````P@`````````$``````````(``````````@``
M``````!$````_O__;P(`````````,!-````````P$P```````$``````````
M!0````(````(````````````````````4P````0````"`````````'`30```
M````<!,```````!X``````````0`````````"``````````8`````````%T`
M```$`````@````````#H$T```````.@3````````,`8````````$````"P``
M``@`````````&`````````!G`````0````8`````````&!I````````8&@``
M`````!,````````````````````$````````````````````8@````$````&
M`````````"P:0```````+!H````````P!```````````````````!```````
M```0`````````&T````!````!@````````!@'D```````&`>````````]#8`
M`````````````````!````````````````````!S`````0````8`````````
M5%5```````!450````````X````````````````````$````````````````
M````>0````$````"`````````&A50```````:%4````````87P``````````
M````````"````````````````````($````!`````@````````"`M$``````
M`("T````````U`````````````````````0```````````````````"/````
M`0````(`````````6+5```````!8M0```````'0#```````````````````(
M````````````````````F0````$````#``````````#`8````````,``````
M```0````````````````````"````````````````````*`````!`````P``
M```````0P&```````!#`````````$`````````````````````@`````````
M``````````"G`````0````,`````````(,!@```````@P`````````@`````
M```````````````(````````````````````K`````8````#`````````"C`
M8```````*,````````#P`0````````4`````````"``````````0````````
M`+4````!`````P`````````8PF```````!C"````````*`(`````````````
M``````@`````````"`````````"^`````0````,`````````0,1@``````!`
MQ````````"0````````````````````(````````````````````Q`````@`
M```#`````````(#$8```````9,0````````(!0``````````````````(```
M`````````````````,D````!`````````````````````````&3$````````
M]P$```````````````````$````````````````````!`````P``````````
M``````````````!;Q@```````-(````````````````````!````````````
&````````
